| Title: | Generates Tipsy or Drunk Praise |
|---|---|
| Description: | This is a joke package, which generates praise using the praise package, then garbles it, as if being delivered by someone tipsy or drunk. |
| Authors: | Ella Kaye [aut, cre], Kelly Bodwin [aut], Collin Schwantes [aut] |
| Maintainer: | Ella Kaye <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-21 09:30:11 UTC |
| Source: | https://github.com/EllaKaye/aperol |
Generates praise with praise::praise(), then repeats some words, and permutes them all.
drunk( repeat_words = 1, repeat_times = 2, template = "You are ${adverb} ${adjective}!" )drunk( repeat_words = 1, repeat_times = 2, template = "You are ${adverb} ${adjective}!" )
repeat_words |
int scalar, the number of words that get repeated |
repeat_times |
an integer-valued (non-negative) vector. If |
template |
character scalar, template for the (non-swapped) praise |
drunk() drunk(2, 2:3) drunk(2, 2, "You are ${creating} a ${adverb} ${adjective} ${rpackage}")drunk() drunk(2, 2:3) drunk(2, 2, "You are ${creating} a ${adverb} ${adjective} ${rpackage}")
Adds a row to the spritz count variable in the the environment
increment_spritz_count(func)increment_spritz_count(func)
func |
Character. Function to be evaluated |
Invisible. Data frame for spritz_count
increment_spritz_count(func = "1+1")increment_spritz_count(func = "1+1")
A thin wrapper around a function (e.g devtools::check()) that provides affirmation after X calls in Y minutes. Praise gets drunker as the number of actual runs exceeds the number of runs in the time frame.
spritz( func = "devtools::check()", runs = 3, minutes = 10, template = "You are ${adverb} ${adjective}!" )spritz( func = "devtools::check()", runs = 3, minutes = 10, template = "You are ${adverb} ${adjective}!" )
func |
Character. A function you expect to run multiple times |
runs |
Numeric. Number of runs in time frame before praise |
minutes |
Numeric. Number of minutes in time frame |
template |
Character. Praise template |
Returns the output of func
## Not run: # default is to run devtools::check() spritz() # with a different function and praise template spritz("devtools::document()", template = "You are ${creating} a ${adverb} ${adjective} ${rpackage}") # change rate depending on speed of devtools::check() spritz(runs = 4, minutes = 15) ## custom function sleep_add <- function() { Sys.sleep(2) out <- 1 + 1 return(out) } spritz(func = "sleep_add()") ## End(Not run)## Not run: # default is to run devtools::check() spritz() # with a different function and praise template spritz("devtools::document()", template = "You are ${creating} a ${adverb} ${adjective} ${rpackage}") # change rate depending on speed of devtools::check() spritz(runs = 4, minutes = 15) ## custom function sleep_add <- function() { Sys.sleep(2) out <- 1 + 1 return(out) } spritz(func = "sleep_add()") ## End(Not run)
Generates praise with praise::praise(), then swaps some words.
tipsy(swaps = 1, template = "You are ${adverb} ${adjective}!")tipsy(swaps = 1, template = "You are ${adverb} ${adjective}!")
swaps |
int scalar, number of word swaps to make |
template |
character scalar, template for the (non-swapped) praise |
tipsy() tipsy(2, "You are ${creating} a ${adverb} ${adjective} ${rpackage}")tipsy() tipsy(2, "You are ${creating} a ${adverb} ${adjective} ${rpackage}")